@@ -31,32 +31,6 @@ sexp_address <- obj_address
 
 # nocov start - These functions are mostly for interactive experimentation
 
-poke_type <- function(x, type) {
-  invisible(.Call(ffi_poke_type, x, type))
-}
-sexp_named <- function(x) {
-  # Don't use `substitute()` because dots might be forwarded
-  arg <- match.call(expand.dots = FALSE)$x
-  .Call(ffi_named, arg, parent.frame())
-}
-
-mark_object <- function(x) {
-  invisible(.Call(ffi_mark_object, x))
-}
-unmark_object <- function(x) {
-  invisible(.Call(ffi_unmark_object, x))
-}
-
-true_length <- function(x) {
-  .Call(ffi_true_length, x)
-}
-env_frame <- function(x) {
-  .Call(ffi_env_frame, x)
-}
-env_hash_table <- function(x) {
-  .Call(ffi_env_hash_table, x)
-}
-
 promise_expr <- function(name, env = caller_env()) {
   .Call(ffi_promise_expr, name, env)
 }
@@ -94,10 +68,10 @@ vec_alloc <- function(type, n) {
 
 # Note that the C-level function has inverted arguments
 find_var <- function(env, sym) {
-  .Call(ffi_find_var, env, sym);
+  .Call(ffi_find_var, env, sym)
 }
 find_var_in_frame <- function(env, sym) {
-  .Call(ffi_find_var, env, sym);
+  .Call(ffi_find_var, env, sym)
 }
 
 chr_get <- function(x, i = 0L) {
