@@ -1,6 +1,8 @@
 #include <rlang.h>
-#include "../internal/utils.h"
-#include "../internal/vec.h"
+#include "env.h"
+#include "internal.h"
+#include "utils.h"
+#include "vec.h"
 
 // From rlang/vec.c
 void r_vec_poke_n(r_obj* x, r_ssize offset,
@@ -324,6 +326,42 @@ r_obj* ffi_dyn_list_poke(r_obj* x, r_obj* i, r_obj* value) {
   return r_null;
 }
 
+// [[ register() ]]
+r_obj* ffi_dyn_lgl_push_back(r_obj* x, r_obj* value) {
+  r_dyn_lgl_push_back(r_shelter_deref(x), r_as_bool(value));
+  return r_null;
+}
+// [[ register() ]]
+r_obj* ffi_dyn_int_push_back(r_obj* x, r_obj* value) {
+  r_dyn_int_push_back(r_shelter_deref(x), r_as_int(value));
+  return r_null;
+}
+// [[ register() ]]
+r_obj* ffi_dyn_dbl_push_back(r_obj* x, r_obj* value) {
+  r_dyn_dbl_push_back(r_shelter_deref(x), r_as_double(value));
+  return r_null;
+}
+// [[ register() ]]
+r_obj* ffi_dyn_cpl_push_back(r_obj* x, r_obj* value) {
+  r_dyn_cpl_push_back(r_shelter_deref(x), r_as_complex(value));
+  return r_null;
+}
+// [[ register() ]]
+r_obj* ffi_dyn_raw_push_back(r_obj* x, r_obj* value) {
+  r_dyn_raw_push_back(r_shelter_deref(x), r_as_char(value));
+  return r_null;
+}
+// [[ register() ]]
+r_obj* ffi_dyn_chr_push_back(r_obj* x, r_obj* value) {
+  r_dyn_chr_push_back(r_shelter_deref(x), value);
+  return r_null;
+}
+// [[ register() ]]
+r_obj* ffi_dyn_list_push_back(r_obj* x, r_obj* value) {
+  r_dyn_list_push_back(r_shelter_deref(x), value);
+  return r_null;
+}
+
 // [[ register() ]]
 r_obj* ffi_has_size_one_bool(void) {
   return r_lgl(sizeof(bool) == 1);
@@ -416,6 +454,9 @@ r_obj* ffi_lof_arr_push_back(r_obj* lof, r_obj* i, r_obj* value) {
 // env.c
 
 r_obj* ffi_env_poke_parent(r_obj* env, r_obj* new_parent) {
+  // For the R level API, we do our own checks on top of
+  // what `r_env_poke_parent()` (really `base::parent.env<-`)
+  // does to throw better user facing error messages
   if (R_IsNamespaceEnv(env)) {
     r_abort("Can't change the parent of a namespace environment");
   }
@@ -435,17 +476,10 @@ r_obj* ffi_env_poke_parent(r_obj* env, r_obj* new_parent) {
     r_abort("Can't change the parent of the empty environment");
   }
 
-  SET_ENCLOS(env, new_parent);
+  r_env_poke_parent(env, new_parent);
   return env;
 }
 
-r_obj* ffi_env_frame(r_obj* env) {
-  return FRAME(env);
-}
-r_obj* ffi_env_hash_table(r_obj* env) {
-  return HASHTAB(env);
-}
-
 r_obj* ffi_env_inherits(r_obj* env, r_obj* ancestor) {
   return r_lgl(r_env_inherits(env, ancestor, r_envs.empty));
 }
@@ -475,26 +509,6 @@ r_obj* ffi_env_bind_list(r_obj* env, r_obj* names, r_obj* data) {
   return r_null;
 }
 
-r_obj* ffi_env_browse(r_obj* env, r_obj* value) {
-  if (r_typeof(env) != R_TYPE_environment) {
-    r_abort("`env` must be an environment.");
-  }
-  if (!r_is_bool(value)) {
-    r_abort("`value` must be a single logical value.");
-  }
-
-  r_obj* old = r_lgl(RDEBUG(env));
-  SET_RDEBUG(env, r_lgl_get(value, 0));
-  return old;
-}
-
-r_obj* ffi_env_is_browsed(r_obj* env) {
-  if (r_typeof(env) != R_TYPE_environment) {
-    r_abort("`env` must be an environment.");
-  }
-  return r_lgl(RDEBUG(env));
-}
-
 r_obj* ffi_ns_registry_env(void) {
   return R_NamespaceRegistry;
 }
@@ -690,9 +704,6 @@ r_obj* ffi_quo_is_null(r_obj* quo) {
 r_obj* ffi_length(r_obj* x) {
   return r_int(r_length(x));
 }
-r_obj* ffi_true_length(r_obj* x) {
-  return r_int(XTRUELENGTH(x));
-}
 
 r_obj* ffi_is_reference(r_obj* x, r_obj* y) {
   return r_lgl(x == y);
@@ -714,19 +725,6 @@ r_obj* ffi_obj_address(r_obj* x) {
   return r_str_as_character(r_obj_address(x));
 }
 
-r_obj* ffi_poke_type(r_obj* x, r_obj* type) {
-  SET_TYPEOF(x, Rf_str2type(r_chr_get_c_string(type, 0)));
-  return x;
-}
-
-r_obj* ffi_mark_object(r_obj* x) {
-  SET_OBJECT(x, 1);
-  return x;
-}
-r_obj* ffi_unmark_object(r_obj* x) {
-  SET_OBJECT(x, 0);
-  return x;
-}
 
 r_obj* rlang_get_promise(r_obj* x, r_obj* env) {
   switch (r_typeof(x)) {
@@ -770,23 +768,6 @@ r_obj* ffi_promise_value(r_obj* x, r_obj* env) {
   }
 }
 
-// Picks up symbols from parent environment to avoid bumping namedness
-// during promise resolution
-r_obj* ffi_named(r_obj* x, r_obj* env) {
-  int n_kept = 0;
-
-  x = PROTECT(Rf_findVarInFrame3(env, x, FALSE));
-  ++n_kept;
-
-  if (TYPEOF(x) == PROMSXP) {
-    x = PROTECT(Rf_eval(x, env));
-    ++n_kept;
-  }
-
-  UNPROTECT(n_kept);
-  return Rf_ScalarInteger(NAMED(x));
-}
-
 r_obj* ffi_find_var(r_obj* env, r_obj* sym) {
   return Rf_findVar(sym, env);
 }
@@ -828,7 +809,7 @@ r_obj* ffi_unpreserve(r_obj* x) {
 // vec.h
 
 r_obj* ffi_vec_alloc(r_obj* type, r_obj* n) {
-  return Rf_allocVector(Rf_str2type(r_chr_get_c_string(type, 0)), r_int_get(n, 0));
+  return r_alloc_vector(Rf_str2type(r_chr_get_c_string(type, 0)), r_int_get(n, 0));
 }
 r_obj* ffi_vec_coerce(r_obj* x, r_obj* type) {
   return Rf_coerceVector(x, Rf_str2type(r_chr_get_c_string(type, 0)));
@@ -1031,6 +1012,16 @@ r_obj* protect_missing(r_obj* x) {
   }
 }
 
+r_obj* ffi_has_private_accessors(void) {
+#ifdef RLANG_USE_PRIVATE_ACCESSORS
+  return r_true;
+#else
+  return r_false;
+#endif
+}
+
+#ifdef RLANG_USE_PRIVATE_ACCESSORS
+
 // [[ register() ]]
 r_obj* ffi_sexp_iterate(r_obj* x, r_obj* fn) {
   struct r_dyn_array* p_out = r_new_dyn_vector(R_TYPE_list, 256);
@@ -1089,3 +1080,5 @@ r_obj* ffi_sexp_iterate(r_obj* x, r_obj* fn) {
   FREE(3);
   return r_dyn_unwrap(p_out);
 }
+
+#endif
