@@ -34,11 +34,11 @@ r_obj* r_env_parent(r_obj* env) {
   if (env == r_envs.empty) {
     r_stop_internal("Can't take the parent of the empty environment.");
   }
+#if R_VERSION >= R_Version(4, 5, 0)
+  return R_ParentEnv(env);
+#else
   return ENCLOS(env);
-}
-static inline
-void r_env_poke_parent(r_obj* env, r_obj* new_parent) {
-  SET_ENCLOS(env, new_parent);
+#endif
 }
 
 static inline
@@ -142,9 +142,15 @@ static inline
 r_obj* r_alloc_empty_environment(r_obj* parent) {
   // Non-hashed environment.
   // Very fast and useful when you aren't getting/setting from the result.
+#if R_VERSION >= R_Version(4, 1, 0)
+  const int hash = 0;
+  const int size = 0; // Not used when `hash = 0`
+  return R_NewEnv(parent, hash, size);
+#else
   r_obj* env = Rf_allocSExp(R_TYPE_environment);
-  r_env_poke_parent(env, parent);
+  SET_ENCLOS(env, parent);
   return env;
+#endif
 }
 
 r_obj* r_env_as_list(r_obj* x);
@@ -157,12 +163,7 @@ void r_env_coalesce(r_obj* env, r_obj* from);
 // Silently ignores bindings that are not defined in `env`.
 static inline
 void r_env_unbind(r_obj* env, r_obj* sym) {
-#if (R_VERSION < R_Version(4, 0, 0))
-  void r__env_unbind(r_obj*, r_obj*);
-  r__env_unbind(env, sym);
-#else
   R_removeVarFromFrame(sym, env);
-#endif
 }
 
 static inline
