@@ -294,9 +294,6 @@ test_that("abort() displays call in error prefix", {
     )
   )
 
-  # errorCondition()
-  skip_if_not_installed("base", "3.6.0")
-
   expect_snapshot(
     run(
       "{
@@ -414,10 +411,12 @@ test_that("error_call() and format_error_call() preserve special syntax ops", {
   )
   expect_snapshot(format_error_call(quote(1 + 2)))
 
+  # fmt: skip
   expect_equal(
     error_call(quote(for (x in y) NULL)),
     quote(for (x in y) NULL)
   )
+  # fmt: skip
   expect_snapshot(format_error_call(quote(for (x in y) NULL)))
 
   expect_snapshot(format_error_call(quote(a %||% b)))
@@ -743,9 +742,12 @@ test_that("`parent = NA` signals a non-chained rethrow", {
     print(err(ff()))
 
     "Wrapped handler"
-    handler1 <- function(cnd, call = caller_env()) handler2(cnd, call)
-    handler2 <- function(cnd, call)
+    handler1 <- function(cnd, call = caller_env()) {
+      handler2(cnd, call)
+    }
+    handler2 <- function(cnd, call) {
       abort(cnd_header(cnd), parent = NA, call = call)
+    }
     hh <- function() {
       withCallingHandlers(
         foo(),
@@ -796,12 +798,13 @@ test_that("if `call` is older than handler caller, use that as bottom", {
   helper <- function(call = caller_env()) {
     try_fetch(
       low_level(call),
-      error = function(cnd)
+      error = function(cnd) {
         abort(
           "Problem.",
           parent = cnd,
           call = call
         )
+      }
     )
   }
 
