@@ -1,28 +1,33 @@
 test_that("cnd_signal() creates muffle restarts", {
-  withCallingHandlers(cnd_signal(cnd("foo")),
-    foo = function(c) {
-      expect_true(rst_exists("rlang_muffle"))
-    }
-  )
+  withCallingHandlers(cnd_signal(cnd("foo")), foo = function(c) {
+    expect_true(rst_exists("rlang_muffle"))
+  })
 })
 
 test_that("signallers support character vectors as `message` parameter", {
   expect_message(inform(c("foo", "*" = "bar")), "foo\n* bar", fixed = TRUE)
   expect_warning(warn(c("foo", "*" = "bar")), "foo\n* bar", fixed = TRUE)
   expect_error(abort(c("foo", "*" = "bar")), "foo\n* bar", fixed = TRUE)
-  expect_condition(signal(c("foo", "*" = "bar"), "quux"), "quux", regex = "foo\n\\* bar")
+  expect_condition(
+    signal(c("foo", "*" = "bar"), "quux"),
+    "quux",
+    regex = "foo\n\\* bar"
+  )
 })
 
 test_that("cnd_signal() and signal() returns NULL invisibly", {
-  expect_identical(withVisible(cnd_signal(cnd("foo"))), withVisible(invisible(NULL)))
+  expect_identical(
+    withVisible(cnd_signal(cnd("foo"))),
+    withVisible(invisible(NULL))
+  )
   expect_identical(withVisible(signal("", "foo")), withVisible(invisible(NULL)))
 })
 
 test_that("signal() accepts character vectors of classes (#195)", {
-  expect <- calling(function(cnd) {
+  expect <- function(cnd) {
     expect_identical(class(cnd), c("foo", "bar", "condition"))
-  })
-  with_handlers(signal("", c("foo", "bar")), foo = expect)
+  }
+  withCallingHandlers(signal("", c("foo", "bar")), foo = expect)
 })
 
 test_that("can pass condition metadata", {
@@ -42,16 +47,29 @@ test_that("can signal and catch interrupts", {
 
 test_that("can signal interrupts with cnd_signal()", {
   intr <- catch_cnd(interrupt())
-  with_handlers(cnd_signal(intr),
+  tryCatch(
+    cnd_signal(intr),
     condition = function(cnd) expect_s3_class(cnd, "interrupt")
   )
 })
 
 test_that("conditions have correct subclasses", {
-  expect_true(inherits_all(expect_condition(signal("", "foo")), c("foo", "condition", "condition")))
-  expect_true(inherits_all(expect_message(inform("", "foo")), c("foo", "message", "condition")))
-  expect_true(inherits_all(expect_warning2(warn("", "foo")), c("foo", "warning", "condition")))
-  expect_true(inherits_all(expect_error(abort("", "foo")), c("foo", "rlang_error", "error", "condition")))
+  expect_true(inherits_all(
+    expect_condition(signal("", "foo")),
+    c("foo", "condition", "condition")
+  ))
+  expect_true(inherits_all(
+    expect_message(inform("", "foo")),
+    c("foo", "message", "condition")
+  ))
+  expect_true(inherits_all(
+    expect_warning2(warn("", "foo")),
+    c("foo", "warning", "condition")
+  ))
+  expect_true(inherits_all(
+    expect_error(abort("", "foo")),
+    c("foo", "rlang_error", "error", "condition")
+  ))
 })
 
 test_that("cnd_signal() creates a backtrace if needed", {
@@ -157,11 +175,19 @@ test_that("warn() and inform() use different periodicity environments", {
   )
 
   expect_message(
-    inform("foo", .frequency = "once", .frequency_id = "warn_inform_different_envs"),
+    inform(
+      "foo",
+      .frequency = "once",
+      .frequency_id = "warn_inform_different_envs"
+    ),
     "foo"
   )
   expect_warning(
-    warn("foo", .frequency = "once", .frequency_id = "warn_inform_different_envs"),
+    warn(
+      "foo",
+      .frequency = "once",
+      .frequency_id = "warn_inform_different_envs"
+    ),
     "foo"
   )
 })
@@ -183,8 +209,8 @@ test_that("messages can be silenced", {
     rlib_message_verbosity = "quiet",
     rlib_warning_verbosity = "quiet"
   )
-  expect_message(inform("foo"), NA)
-  expect_warning(warn("foo"), NA)
+  expect_no_message(inform("foo"))
+  expect_no_warning(warn("foo"))
 })
 
 test_that("`.frequency_id` is mandatory", {
@@ -198,24 +224,52 @@ test_that("cnd_signal() is a no-op with `NULL`", {
 test_that("`inform()` behaves consistently in interactive and non-interactive sessions (#1037)", {
   # Default behaviour
   out1 <- Rscript(shQuote(c("--vanilla", "-e", "rlang::inform('foo')")))
-  out2 <- Rscript(shQuote(c("--vanilla", "-e", "rlang::with_interactive(rlang::inform('foo'))")))
+  out2 <- Rscript(shQuote(c(
+    "--vanilla",
+    "-e",
+    "rlang::with_interactive(rlang::inform('foo'))"
+  )))
   expect_equal(out1$out, "foo")
   expect_equal(out1$out, out2$out)
 
   # Sinked behaviour
-  out1 <- Rscript(shQuote(c("--vanilla", "-e", "capture.output(rlang::inform('foo'))")))
-  out2 <- Rscript(shQuote(c("--vanilla", "-e", "rlang::with_interactive(capture.output(rlang::inform('foo')))")))
+  out1 <- Rscript(shQuote(c(
+    "--vanilla",
+    "-e",
+    "capture.output(rlang::inform('foo'))"
+  )))
+  out2 <- Rscript(shQuote(c(
+    "--vanilla",
+    "-e",
+    "rlang::with_interactive(capture.output(rlang::inform('foo')))"
+  )))
   expect_equal(out1$out, c("foo", "character(0)"))
   expect_equal(out1$out, out2$out)
 })
 
 test_that("`inform()` and `warn()` with recurrent footer handle newlines correctly", {
   expect_snapshot({
-    inform("foo", .frequency = "regularly", .frequency_id = as.character(runif(1)))
-    inform("bar", .frequency = "regularly", .frequency_id = as.character(runif(1)))
+    inform(
+      "foo",
+      .frequency = "regularly",
+      .frequency_id = as.character(runif(1))
+    )
+    inform(
+      "bar",
+      .frequency = "regularly",
+      .frequency_id = as.character(runif(1))
+    )
 
-    warn("foo", .frequency = "regularly", .frequency_id = as.character(runif(1)))
-    warn("bar", .frequency = "regularly", .frequency_id = as.character(runif(1)))
+    warn(
+      "foo",
+      .frequency = "regularly",
+      .frequency_id = as.character(runif(1))
+    )
+    warn(
+      "bar",
+      .frequency = "regularly",
+      .frequency_id = as.character(runif(1))
+    )
   })
 })
 
@@ -235,8 +289,6 @@ test_that("`warning.length` is increased (#1211)", {
 })
 
 test_that("interrupt() doesn't fail when interrupts are suspended (#1224)", {
-  skip_if_not_installed("base", "3.5.0")
-
   out <- FALSE
 
   tryCatch(
@@ -283,11 +335,11 @@ test_that("can pass `use_cli_format` as condition field", {
 })
 
 test_that("signal functions check inputs", {
-  expect_snapshot({
-    (expect_error(abort(error_cnd("foo"))))
-    (expect_error(inform(error_cnd("foo"))))
-    (expect_error(warn(class = error_cnd("foo"))))
-    (expect_error(abort("foo", call = base::call)))
+  expect_snapshot(error = TRUE, cnd_class = TRUE, {
+    abort(error_cnd("foo"))
+    inform(error_cnd("foo"))
+    warn(class = error_cnd("foo"))
+    abort("foo", call = base::call)
   })
 })
 
@@ -299,13 +351,47 @@ test_that("cnd_signal() sets call", {
   expect_equal(cnd$call, quote(f()))
 })
 
+test_that("can reset verbosity", {
+  on.exit(reset_warning_verbosity("test_reset_verbosity"))
+
+  expect_warning(
+    warn("foo", .frequency = "once", .frequency_id = "test_reset_verbosity")
+  )
+  expect_no_warning(
+    warn("foo", .frequency = "once", .frequency_id = "test_reset_verbosity")
+  )
+
+  reset_warning_verbosity("test_reset_verbosity")
+
+  expect_warning(
+    warn("foo", .frequency = "once", .frequency_id = "test_reset_verbosity")
+  )
+})
+
+test_that("downgraded conditions are not inherited (#1573)", {
+  cnd <- catch_cnd(warn("", parent = error_cnd()))
+  expect_false(cnd$rlang$inherit)
+
+  cnd <- catch_cnd(inform("", parent = error_cnd()))
+  expect_false(cnd$rlang$inherit)
+
+  cnd <- catch_cnd(inform("", parent = warning_cnd()))
+  expect_false(cnd$rlang$inherit)
+
+  cnd <- catch_cnd(warn("", parent = error_cnd(), .inherit = TRUE))
+  expect_true(cnd$rlang$inherit)
+
+  cnd <- catch_cnd(inform("", parent = error_cnd(), .inherit = TRUE))
+  expect_true(cnd$rlang$inherit)
+
+  cnd <- catch_cnd(inform("", parent = warning_cnd(), .inherit = TRUE))
+  expect_true(cnd$rlang$inherit)
+})
+
 
 # Lifecycle ----------------------------------------------------------
 
 test_that("error_cnd() still accepts `.subclass`", {
-  # <deprecatedWarning>
-  skip_if(getRversion() < "3.6.0")
-
   local_options(
     lifecycle_disable_warnings = FALSE,
     force_subclass_deprecation = TRUE
