@@ -15,7 +15,10 @@ test_that("eval_tidy uses quosure environment", {
 test_that("data must be uniquely named", {
   expect_error(eval_tidy(NULL, list(x = 1, x = 2)), "has duplicate columns")
 
-  data <- set_names(data.frame(x = 1, x = 2, y = 3, y = 4), c("x", "x", "y", "y"))
+  data <- set_names(
+    data.frame(x = 1, x = 2, y = 3, y = 4),
+    c("x", "x", "y", "y")
+  )
   expect_error(eval_tidy(NULL, data), "has duplicate columns")
 })
 
@@ -38,8 +41,14 @@ test_that("pronouns resolve ambiguity looks first in `data`", {
 })
 
 test_that("pronouns complain about missing values", {
-  expect_data_pronoun_error(eval_tidy(quo(.data$x), list()), "Column `x` not found in `.data`")
-  expect_data_pronoun_error(eval_tidy(quo(.data$x), data.frame()), "Column `x` not found in `.data`")
+  expect_data_pronoun_error(
+    eval_tidy(quo(.data$x), list()),
+    "Column `x` not found in `.data`"
+  )
+  expect_data_pronoun_error(
+    eval_tidy(quo(.data$x), data.frame()),
+    "Column `x` not found in `.data`"
+  )
 })
 
 test_that("nested quosures look in their own env", {
@@ -71,16 +80,16 @@ test_that("unquoted formulas can use data", {
 
   z <- 10
   expect_identical(eval_tidy(f2(), list(x = 1)), 101)
-  expect_identical(eval_tidy(quo(!! f1()), data = list(x = 1)), 101)
-  expect_identical(eval_tidy(quo(!! f2()), data = list(x = 1)), 101)
+  expect_identical(eval_tidy(quo(!!f1()), data = list(x = 1)), 101)
+  expect_identical(eval_tidy(quo(!!f2()), data = list(x = 1)), 101)
 })
 
 test_that("bare formulas are not evaluated", {
   f <- local(~x)
-  expect_identical(eval_tidy(quo(!! f)), f)
+  expect_identical(eval_tidy(quo(!!f)), f)
 
   f <- a ~ b
-  expect_identical(eval_tidy(quo(!! f)), f)
+  expect_identical(eval_tidy(quo(!!f)), f)
 })
 
 test_that("quosures are not evaluated if not forced", {
@@ -88,13 +97,13 @@ test_that("quosures are not evaluated if not forced", {
     if (force) arg else "bar"
   }
 
-  f1 <- quo(fn(!! quo(stop("forced!")), force = FALSE))
-  f2 <- quo(fn(!! local(quo(stop("forced!"))), force = FALSE))
+  f1 <- quo(fn(!!quo(stop("forced!")), force = FALSE))
+  f2 <- quo(fn(!!local(quo(stop("forced!"))), force = FALSE))
   expect_identical(eval_tidy(f1), "bar")
   expect_identical(eval_tidy(f2), "bar")
 
-  f_forced1 <- quo(fn(!! quo(stop("forced!")), force = TRUE))
-  f_forced2 <- quo(fn(!! local(quo(stop("forced!"))), force = TRUE))
+  f_forced1 <- quo(fn(!!quo(stop("forced!")), force = TRUE))
+  f_forced2 <- quo(fn(!!local(quo(stop("forced!"))), force = TRUE))
   expect_error(eval_tidy(f_forced1), "forced!")
   expect_error(eval_tidy(f_forced2), "forced!")
 })
@@ -109,18 +118,19 @@ test_that("can unquote captured arguments", {
 test_that("quosures are evaluated recursively", {
   foo <- "bar"
   expect_identical(eval_tidy(quo(foo)), "bar")
-  expect_identical(eval_tidy(quo(!!quo(!! quo(foo)))), "bar")
+  expect_identical(eval_tidy(quo(!!quo(!!quo(foo)))), "bar")
 })
 
 test_that("quosures have lazy semantics", {
   fn <- function(arg) "unforced"
-  expect_identical(eval_tidy(quo(fn(~stop()))), "unforced")
+  expect_identical(eval_tidy(quo(fn(~ stop()))), "unforced")
 })
 
 test_that("can unquote hygienically within captured arg", {
   fn <- function(df, arg) eval_tidy(enquo(arg), df)
 
-  foo <- "bar"; var <- quo(foo)
+  foo <- "bar"
+  var <- quo(foo)
   expect_identical(fn(mtcars, list(var, !!var)), list(quo(foo), "bar"))
 
   var <- quo(cyl)
@@ -132,8 +142,8 @@ test_that("can unquote hygienically within captured arg", {
     ignore_formula_env = TRUE
   )
   expect_equal(
-    fn(mtcars, list(~~var, !!quo(var), !!quo(quo(var)))),
-    list(~~var, quo(cyl), quo(var)),
+    fn(mtcars, list(~ ~var, !!quo(var), !!quo(quo(var)))),
+    list(~ ~var, quo(cyl), quo(var)),
     ignore_formula_env = TRUE
   )
 })
@@ -147,7 +157,13 @@ test_that("can unquote for old-style NSE functions", {
 
 test_that("all quosures in the call are evaluated", {
   foobar <- function(x) paste0("foo", x)
-  x <- new_quosure(call("foobar", local({ bar <- "bar"; quo(bar) })))
+  x <- new_quosure(call(
+    "foobar",
+    local({
+      bar <- "bar"
+      quo(bar)
+    })
+  ))
   f <- new_quosure(call("identity", x))
   expect_identical(eval_tidy(f), "foobar")
 })
@@ -172,7 +188,7 @@ test_that("inner formulas are rechained to evaluation env", {
   env <- child_env(NULL)
   f1 <- quo(env$eval_env1 <- current_env())
   f2 <- quo({
-    !! f1
+    !!f1
     env$eval_env2 <- current_env()
   })
 
@@ -182,12 +198,15 @@ test_that("inner formulas are rechained to evaluation env", {
 })
 
 test_that("empty quosure self-evaluates", {
-  quo <- quo(is_missing(!! quo()))
+  quo <- quo(is_missing(!!quo()))
   expect_true(eval_tidy(quo))
 })
 
 test_that("cannot replace elements of pronouns", {
-  expect_error(eval_tidy(quo(.data$foo <- "bar"), mtcars), "Can't modify the data pronoun")
+  expect_error(
+    eval_tidy(quo(.data$foo <- "bar"), mtcars),
+    "Can't modify the data pronoun"
+  )
 })
 
 test_that("formulas are not evaluated as quosures", {
@@ -211,7 +230,7 @@ test_that(".env pronoun refers to current quosure (#174)", {
 
   outer_quo <- local({
     var <- "outer"
-    quo(identity(!! inner_quo))
+    quo(identity(!!inner_quo))
   })
 
   expect_identical(eval_tidy(outer_quo, list()), "inner")
@@ -233,7 +252,7 @@ test_that("can call tilde with named arguments (#226)", {
 test_that("Arguments to formulas are not stripped from their attributes (#227)", {
   quo <- quo(x)
 
-  f <- eval_tidy(quo(~!!quo))
+  f <- eval_tidy(quo(~ !!quo))
   expect_identical(f_rhs(f), quo)
 
   f <- eval_tidy(quo(!!quo(x) ~ a))
@@ -292,7 +311,7 @@ test_that("inner formulas are evaluated in the current frame", {
   envs <- eval_tidy(quo)
   expect_identical(envs$f_env, envs$env)
 
-  quo <- quo(as_function(~list(f_env = get_env(~foo), env = current_env()))())
+  quo <- quo(as_function(~ list(f_env = get_env(~foo), env = current_env()))())
   envs <- eval_tidy(quo)
   expect_identical(envs$f_env, envs$env)
 })
@@ -357,7 +376,7 @@ test_that("data_pronoun_name() extracts name", {
 })
 
 test_that(".data pronoun walks the ancestry of environments", {
-  e  <- 0
+  e <- 0
   e1 <- env(a = 1, b = 1, c = 1)
   e2 <- env(a = 2, b = 2, e1)
   e3 <- env(a = 3, e2)
@@ -372,16 +391,28 @@ test_that(".data pronoun walks the ancestry of environments", {
   expect_data_pronoun_error(.data$e, "Column `e` not found in `.data`")
   expect_data_pronoun_error(.data$.data, "Column `.data` not found in `.data`")
   expect_data_pronoun_error(.data$.env, "Column `.env` not found in `.data`")
-  expect_data_pronoun_error(.data$.top_env, "Column `.top_env` not found in `.data`")
+  expect_data_pronoun_error(
+    .data$.top_env,
+    "Column `.top_env` not found in `.data`"
+  )
 
   expect_equal(.data[["a"]], 3)
   expect_equal(.data[["b"]], 2)
   expect_equal(.data[["c"]], 1)
   expect_data_pronoun_error(.data[["d"]], "Column `d` not found in `.data`")
   expect_data_pronoun_error(.data[["e"]], "Column `e` not found in `.data`")
-  expect_data_pronoun_error(.data[[".data"]], "Column `.data` not found in `.data`")
-  expect_data_pronoun_error(.data[[".env"]], "Column `.env` not found in `.data`")
-  expect_data_pronoun_error(.data[[".top_env"]], "Column `.top_env` not found in `.data`")
+  expect_data_pronoun_error(
+    .data[[".data"]],
+    "Column `.data` not found in `.data`"
+  )
+  expect_data_pronoun_error(
+    .data[[".env"]],
+    "Column `.env` not found in `.data`"
+  )
+  expect_data_pronoun_error(
+    .data[[".top_env"]],
+    "Column `.top_env` not found in `.data`"
+  )
 
   expect_error(.data["a"])
 })
@@ -406,13 +437,16 @@ test_that("leaked quosure masks are not mistaken with data masks", {
 })
 
 test_that("quosures look for data masks lexically", {
-  out <- eval_tidy(data = mtcars, expr({
-    fn <- as_function(~ !!quo(cyl))
-    list(
-      fn(),
-      local(!!quo(disp))
-    )
-  }))
+  out <- eval_tidy(
+    data = mtcars,
+    expr({
+      fn <- as_function(~ !!quo(cyl))
+      list(
+        fn(),
+        local(!!quo(disp))
+      )
+    })
+  )
   expect_identical(out, list(mtcars$cyl, mtcars$disp))
 })
 
@@ -453,18 +487,6 @@ test_that("can't take the names() and length() of the `.data` pronoun", {
   expect_named(pronoun, chr())
 })
 
-test_that("eval_tidy() does not infloop when the quosure inherits from the mask", {
-  mask <- as_data_mask(list(foo = 1))
-  quo <- new_quosure(quote(foo), mask)
-  expect_identical(eval_tidy(quo, mask), 1)
-
-  top <- env(foo = 1)
-  bottom <- env(top)
-  mask <- new_data_mask(bottom, top)
-  quo <- new_quosure(quote(foo), top)
-  expect_identical(eval_tidy(quo, mask), 1)
-})
-
 test_that(".data pronoun handles promises (#908)", {
   e <- env()
   env_bind_lazy(e, a = c(1))
@@ -510,14 +532,14 @@ test_that("eval_tidy() has dimnames method (#1265)", {
 })
 
 test_that("fake pronoun fails informatively", {
-  expect_snapshot({
+  expect_snapshot(error = TRUE, cnd_class = TRUE, {
     "Fake pronouns"
 
     f <- function() .data$foo
-    (expect_error(f(), "subset"))
+    f()
 
     f <- function() .data[["foo"]]
-    (expect_error(f(), "subset"))
+    f()
   })
 })
 
