@@ -1,11 +1,3 @@
-test_that("poke_type() changes object type", {
-  x <- new_node(quote(foo), NULL)
-  out <- withVisible(poke_type(x, "language"))
-  expect_false(out$visible)
-  expect_identical(out$value, x)
-  expect_identical(typeof(x), "language")
-})
-
 test_that("can access promise properties", {
   fn <- function(...) {
     list(node_car(get("...")))
@@ -29,7 +21,10 @@ test_that("can pluck promise value", {
   fn <- function(x) promise_value("x")
   expect_identical(fn(foo), sym("R_UnboundValue"))
 
-  fn <- function(x) { force(x); promise_value("x") }
+  fn <- function(x) {
+    force(x)
+    promise_value("x")
+  }
   foo <- "foo"
   expect_identical(fn(foo), "foo")
 })
