@@ -1,11 +1,9 @@
-context("weakref")
-
 test_that("weakref with key and no value allows key to be GC'd", {
   # This is the case when a weakref is used like a weak pointer (with no
   # value).
   k <- env()
   w_finalized <- FALSE
-  w <- new_weakref(key = k, finalizer = function(e) { message("w finalized"); w_finalized <<- TRUE })
+  w <- new_weakref(key = k, finalizer = function(e) w_finalized <<- TRUE)
 
   expect_identical(wref_key(w), k)
   expect_identical(wref_value(w), NULL)
@@ -22,18 +20,24 @@ test_that("key keeps value alive", {
   # Key and value: key keeps value alive
   k <- env()
   k_finalized <- FALSE
-  reg.finalizer(k, function(e) { k_finalized <<- TRUE })
+  reg.finalizer(k, function(e) {
+    k_finalized <<- TRUE
+  })
 
   v <- env()
   v$x <- "hello"
   v_finalized <- FALSE
-  reg.finalizer(v, function(e) { v_finalized <<- TRUE })
+  reg.finalizer(v, function(e) {
+    v_finalized <<- TRUE
+  })
 
   w_finalized <- FALSE
   w <- new_weakref(
     key = k,
     value = v,
-    finalizer = function(e) { w_finalized <<- TRUE }
+    finalizer = function(e) {
+      w_finalized <<- TRUE
+    }
   )
   expect_identical(wref_key(w), k)
   expect_identical(wref_value(w), v)
